[binutils-gdb] gdb: Improve documentation comment on language_defn::print_type

Andrew Burgess aburgess@sourceware.org
Fri Oct 23 10:06:24 GMT 2020


https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=88cefd9be076ea1f66b933be484d82f200b0f6c3

commit 88cefd9be076ea1f66b933be484d82f200b0f6c3
Author: Andrew Burgess <andrew.burgess@embecosm.com>
Date:   Mon Sep 21 12:10:04 2020 +0100

    gdb: Improve documentation comment on language_defn::print_type
    
    Improves the comment at the declaration of language_defn::print_type.
    
    There should be no user visible changes after this commit.
    
    gdb/ChangeLog:
    
            * language.h (language_defn::print_type): Add variable names in
            declaration, and update header comment.

Diff:
---
 gdb/ChangeLog  |  5 +++++
 gdb/language.h | 12 ++++++++----
 2 files changed, 13 insertions(+), 4 deletions(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 1a4a03cd34c..6b870f56e64 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,8 @@
+2020-10-23  Andrew Burgess  <andrew.burgess@embecosm.com>
+
+	* language.h (language_defn::print_type): Add variable names in
+	declaration, and update header comment.
+
 2020-10-23  Andrew Burgess  <andrew.burgess@embecosm.com>
 
 	* ada-lang.c (ada_language::demangle): Rename to...
diff --git a/gdb/language.h b/gdb/language.h
index 106d7667527..951343fd9a3 100644
--- a/gdb/language.h
+++ b/gdb/language.h
@@ -333,10 +333,14 @@ struct language_defn
     return nullptr;
   }
 
-  /* Print a type using syntax appropriate for this language.  */
-
-  virtual void print_type (struct type *, const char *, struct ui_file *, int,
-			   int, const struct type_print_options *) const = 0;
+  /* Print TYPE to STREAM using syntax appropriate for this language.
+     LEVEL is the depth to indent lines by.  VARSTRING, if not NULL or the
+     empty string, is the name of a variable and TYPE should be printed in
+     the form of a declaration of a variable named VARSTRING.  */
+
+  virtual void print_type (struct type *type, const char *varstring,
+			   struct ui_file *stream, int show, int level,
+			   const struct type_print_options *flags) const = 0;
 
   /* PC is possibly an unknown languages trampoline.
      If that PC falls in a trampoline belonging to this language, return


More information about the Gdb-cvs mailing list